@@ -113,9 +113,10 @@ class PushCommand(ArgumentCommand):
         try:
             container = get_container(self.options)
             if not container.is_built():
-                container.build()
-            container.push()
-            print("{} pushed".format(container.tag))
+                container.build(latest=self.options.latest)
+            tags = container.push(self.options.latest)
+            for tag in tags:
+                print("{} pushed".format(tag))
             return 0
         except Error as e:
             print(e)
